=======
whispyr
=======


.. image:: https://img.shields.io/pypi/v/whispyr.svg
        :target: https://pypi.python.org/pypi/whispyr

.. image:: https://img.shields.io/travis/velimir0xff/whispyr.svg
        :target: https://travis-ci.org/velimir0xff/whispyr

.. image:: https://img.shields.io/coveralls/github/velimir0xff/whispyr/master.svg
        :alt: Code coverage

.. image:: https://readthedocs.org/projects/whispyr/badge/?version=latest
        :target: https://whispyr.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




a python client library for whispir.io


* Free software: MIT license
* Documentation: https://whispyr.readthedocs.io.


Features
--------

* Very thin client for `whispir.io` API.
* Adding a new whispir endpoint as easy as declaring a new class (almost)
* Configurable retry policies
* Decent test code coverage
